@@ -2,7 +2,7 @@
 #define _PLUGIN_KATE_HELLOWORLD_H_
 
 #include <kate/application.h>
-#include <kate/docmanager.h>
+#include <kate/documentmanager.h>
 #include <kate/document.h>
 #include <kate/mainwindow.h>
 #include <kate/plugin.h>
@@ -26,7 +26,7 @@ class KatePluginFactory : public KLibFactory
     static KInstance* s_instance;
 };
 
-class KatePluginHelloWorld : public Kate::Plugin
+class KatePluginHelloWorld : public Kate::Plugin, Kate::PluginViewInterface
 {
   Q_OBJECT
 
@@ -34,10 +34,14 @@ class KatePluginHelloWorld : public Kate::Plugin
     KatePluginHelloWorld( QObject* parent = 0, const char* name = 0 );
     virtual ~KatePluginHelloWorld();
 
-    Kate::PluginView *createView (Kate::MainWindow *win);
-
+    void addView (Kate::MainWindow *win);
+    void removeView (Kate::MainWindow *win);
+    
   public slots:
-    void slotInsertHello();
+    void slotInsertHello();  
+    
+  private:
+    QPtrList<class PluginView> m_views; 
 };
 
 #endif
