@@ -34,7 +34,7 @@ class PluginView : public KXMLGUIClient
     Kate::MainWindow *win;
 };
 
-K_EXPORT_COMPONENT_FACTORY( kateopenheaderplugin, KGenericFactory<PluginKateOpenHeader>( "kateopenheader" ) );
+K_EXPORT_COMPONENT_FACTORY( kateopenheaderplugin, KGenericFactory<PluginKateOpenHeader>( "kateopenheader" ) )
 
 PluginKateOpenHeader::PluginKateOpenHeader( QObject* parent, const char* name, const QStringList& )
     : Kate::Plugin ( (Kate::Application *)parent, name )
