@@ -28,7 +28,7 @@
 
 typedef KGenericFactory<KFolderPlugin> KFolderFactory;
 
-K_EXPORT_COMPONENT_FACTORY(kfile_folder, KFolderFactory( "kfile_folder" ));
+K_EXPORT_COMPONENT_FACTORY(kfile_folder, KFolderFactory( "kfile_folder" ))
 
 KFolderPlugin::KFolderPlugin(QObject *parent, const char *name,
                        const QStringList &args)
