@@ -28,7 +28,7 @@
 
 typedef KGenericFactory<KTxtPlugin> TxtFactory;
 
-K_EXPORT_COMPONENT_FACTORY(kfile_txt, TxtFactory("kfile_txt"));
+K_EXPORT_COMPONENT_FACTORY(kfile_txt, TxtFactory("kfile_txt"))
 
 KTxtPlugin::KTxtPlugin(QObject *parent, const char *name,
         const QStringList &args) : KFilePlugin(parent, name, args)
