@@ -21,7 +21,7 @@
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
-#include <fstream.h>
+#include <fstream>
 #include <stdio.h>
 
 #ifdef __osf__
@@ -67,11 +67,6 @@ void KSample::Sample::fill(unsigned scale)
   used = scale * 30; used /= 100;
   cached = scale * 20; cached /= 100;
   sused = scale * 25; sused /= 100;
-  pout = scale * 10; pout /= 100;
-  pin = scale * 20; pin /= 100;
-  swout = scale * 30; swout /= 100;
-  swin = scale * 15; swin /= 100;
-  cswitches = scale * 75; cswitches /= 100;
 }
 
 // -- KSample definition -------------------------------------------------
@@ -102,6 +97,8 @@ KSample::KSample(KTimeMon *t, bool a, unsigned p, unsigned s, unsigned c) :
     exit(1);
   }
 
+  fcntl( memFD,F_SETFD, FD_CLOEXEC );
+
   snprintf(file, sizeof(file), "%s/%s", proc, STAT_NAME);
   if ((statFD = open(file, O_RDONLY)) == -1) {
     KMessageBox::error(timemon,
@@ -111,6 +108,8 @@ KSample::KSample(KTimeMon *t, bool a, unsigned p, unsigned s, unsigned c) :
     exit(1);
   }
 
+  fcntl( statFD,F_SETFD, FD_CLOEXEC );
+
 #elif defined (__sun__)
   if ((kc = kstat_open()) == 0) {
     KMessageBox::error(timemon, i18n("Unable to initialize the 'kstat' library. "
@@ -147,7 +146,7 @@ KSample::~KSample()
 // Parse /etc/mtab to determine the proc filesystem mount point.
 void KSample::parseMtab(char *dest)
 {
-    ifstream *mtab = new ifstream(MTAB_NAME);
+    std::ifstream *mtab = new std::ifstream(MTAB_NAME);
     if (!mtab->good()) {
         KMessageBox::error(timemon, i18n("Unable to open file '%1' to determine where the proc "
                                          "filesystem is mounted. The diagnostics are:\n%2\n"
@@ -242,6 +241,18 @@ void KSample::nonfatal(const QString& msg)
 // -----------------------------------------------------------------------------
 // Read a new sample from the files or whatever resource the OS implements
 
+/* For 2.5 kernels */
+static inline void
+scan_one(const char* buff, const char *key, unsigned long int* val)
+{
+        char *b = strstr(buff, key);
+        if (b) {
+                b = strstr(b, " ");
+                if (b)
+                        sscanf(b, " %lu", val);
+        }
+}
+
 void KSample::readSample()
 {
     sample.cpus = 0;            // just to make sure...
@@ -283,6 +294,12 @@ void KSample::readSample()
         l++;
     }
 
+    if ( ( p = strstr(buffer, "Slab:") ) ) {
+        unsigned long slabs;
+        sscanf(p + 5, "%lu kB", &slabs);
+        sample.buffers += slabs;
+    }
+
     lseek(statFD, 0, 0);
     if ((l = read(statFD, buffer, sizeof(buffer)-1)) < 0)
         fatal(i18n("Unable to read the system usage file '%1/%2'.\n"
@@ -290,7 +307,7 @@ void KSample::readSample()
 
     buffer[l] = '\0';
 
-    bool ok = (sscanf(buffer, "cpu %lu %lu %lu %lu\n", &sample.user,
+    bool ok = (sscanf(buffer, "cpu %lu %lu %lu %lu", &sample.user,
                       &sample.nice, &sample.kernel, &sample.idle) == 4);
 
     if (ok) {
@@ -301,7 +318,7 @@ void KSample::readSample()
             if ((p = strstr(buffer, cpuname)) == NULL) break;
 
             unsigned long u, n, k, i;
-            ok = sscanf(p, "cpu%*d %lu %lu %lu %lu\n", &u, &n, &k, &i);
+            ok = sscanf(p, "cpu%*d %lu %lu %lu %lu", &u, &n, &k, &i);
             if (!ok) break;
 
             sample.smptotal[l] = u+n+k+i;
@@ -310,28 +327,6 @@ void KSample::readSample()
     }
     sample.cpus = l;
 
-    if (ok) {
-        if ((p = strstr(buffer, "page")) == NULL) ok = false;
-        else ok = (sscanf(p, "page %lu %lu\n", &sample.pin, &sample.pout) == 2);
-    }
-
-    if (ok) {
-        if ((p = strstr(buffer, "swap")) == NULL) ok = false;
-        else ok = (sscanf(p, "swap %lu %lu\n", &sample.swin, &sample.swout) == 2);
-    }
-
-    if (ok) {
-        if ((p = strstr(buffer, "ctxt")) == NULL) ok = false;
-        else ok = (sscanf(p, "ctxt %lu\n", &sample.cswitches) == 1);
-    }
-
-    if (!ok)
-        fatal(i18n("The system usage file '%1/%2' "
-                   "seems to use a different file format than expected.\n"
-                   "Maybe your version of the proc filesystem is "
-                   "incompatible with supported versions. "
-		   "Please contact the maintainer at mueller@kde.org who will try to sort this out.").arg(proc).arg(STAT_NAME));
-
 #elif defined(__osf__)          // in OSF/2, we can use table()
 
     QString msg = i18n("Unable to obtain system information.\n"
@@ -366,19 +361,6 @@ void KSample::readSample()
     sample.stotal = swapinfo.size;
     sample.sfree = swapinfo.free;
 
-    struct tbl_paging paging;
-    if (table(TBL_PAGING, 0, &paging, 1, sizeof(paging)) != 1)
-        fatal(msg.arg("TBL_PAGING"));
-
-    sample.pin = sample.swin = paging.v_pgpgin; // MM no separate swap
-    sample.pout = sample.swout = paging.v_pgout;
-
-    struct tbl_intr intr;
-    if (table(TBL_INTR, 0, &intr, 1, sizeof(intr)) != 1)
-        fatal(msg.arg("TBL_INTR"));
-
-    sample.cswitches = intr.in_context;
-
 #elif defined(__sun__)
     kstat_t *ksp;
 
@@ -395,8 +377,6 @@ void KSample::readSample()
                    "Please contact the maintainer at mueller@kde.org who will try to sort this out."));
 
     sample.user = sample.nice = sample.kernel = sample.idle = 0;
-    sample.pin = sample.pout = sample.swin = sample.swout = 0;
-    sample.cswitches = 0;
     sample.stotal = sample.sfree = 0;
 
     int cpus = 0;
@@ -416,13 +396,6 @@ void KSample::readSample()
         sample.nice += cstat.cpu_sysinfo.cpu[3] / sample.cpus;
         sample.kernel += cstat.cpu_sysinfo.cpu[2] / sample.cpus;
         sample.idle += cstat.cpu_sysinfo.cpu[0] / sample.cpus;
-
-        sample.pin += cstat.cpu_vminfo.pgin / sample.cpus;
-        sample.pout += cstat.cpu_vminfo.pgout / sample.cpus;
-        sample.swin += cstat.cpu_vminfo.swapin / sample.cpus;
-        sample.swout += cstat.cpu_vminfo.swapout / sample.cpus;
-
-        sample.cswitches += cstat.cpu_sysinfo.pswitch / sample.cpus;
     }
 
     if (cpus != sample.cpus)
@@ -549,14 +522,6 @@ KSample::Sample KSample::getRawSample()
         diff.smpbusy[i] -= oldSample.smpbusy[i];
     }
 
-    diff.pin -= oldSample.pin;
-    diff.pout -= oldSample.pout;
-
-    diff.swin -= oldSample.swin;
-    diff.swout -= oldSample.swout;
-
-    diff.cswitches -= oldSample.cswitches;
-
     return diff;
 }
 
@@ -595,35 +560,6 @@ KSample::Sample KSample::getSample(unsigned scale)
     s.sused = doScale(s.sused, scale, s.stotal);
     makeMBytes(s.stotal);
 
-    s.pin *= scale;
-    s.pout *= scale;
-    unsigned page = (s.pin + s.pout) / 2;
-
-    if (autoscale && page > 0 &&                // autoscale
-        (page / pageScale > scale / 2 || page / pageScale < 1)) {
-        pageScale = page / (scale/4);
-    }
-    s.pin = doScale(s.pin, 1, pageScale);
-    s.pout = doScale(s.pout, 1, pageScale);
-
-    s.swin *= scale;
-    s.swout *= scale;
-    unsigned swap = (s.swin + s.swout) / 2;
-
-    if (autoscale && swap > 0 &&                // autoscale
-        (swap / swapScale > scale / 2 || swap / swapScale < 1)) {
-        swapScale = swap / (scale/4);
-    }
-    s.swin = doScale(s.swin, 1, swapScale);
-    s.swout = doScale(s.swout, 1, swapScale);
-
-    s.cswitches *= scale;
-    if (autoscale && s.cswitches > 0 && // auto scale
-        (s.cswitches / cxScale > scale || s.cswitches / cxScale < 2)) {
-        cxScale = s.cswitches/(scale/2);
-    }
-    s.cswitches = doScale(s.cswitches, 1, cxScale);
-
     return s;
 }
 
