@@ -16,7 +16,8 @@
 #define TIMEMON_H
 
 #include <qtooltip.h>
-#include <qpopupmenu.h>
+#include <kiconloader.h>
+#include <kpopupmenu.h>
 #include <kpanelapplet.h>
 
 // -- global constants ---------------------------------------------------
@@ -86,7 +87,7 @@ private:
     unsigned interval;
     bool autoScale;
     unsigned pageScale, swapScale, ctxScale;
-    QPopupMenu* menu;
+    KPopupMenu* menu;
     KHelpMenu* hmenu;
     QTimer* timer;
     KConfDialog *configDialog;
