@@ -2,7 +2,7 @@
                           mediacontrol.cpp  -  main file of the applet
                              -------------------
     begin                : Tue Apr 25 11:53:11 CEST 2000
-    copyright            : (C) 2000-2002 by Stefan Gehn
+    copyright            : (C) 2000-2003 by Stefan Gehn
     email                : sgehn@gmx.net
  ***************************************************************************/
 
@@ -33,7 +33,7 @@
 #include <qstyle.h>
 #include <qpainter.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kipc.h>
 #include <kglobal.h>
 #include <kiconloader.h>
@@ -48,16 +48,13 @@ extern "C"
 	KPanelApplet *init( QWidget *parent, const QString &configFile)
 	{
 		KGlobal::locale()->insertCatalogue("mediacontrol");
-
 		return new MediaControl(configFile, KPanelApplet::Normal,
 			KPanelApplet::About | KPanelApplet::Preferences, parent, "mediacontrol");
 	}
 }
 
-
 // ====================================================================================
 
-
 class MediaControlToolTip : public QToolTip
 {
 	public:
@@ -77,13 +74,11 @@ class MediaControlToolTip : public QToolTip
 		PlayerInterface *mPlayer;
 };
 
-
 // ====================================================================================
 
-
 MediaControl::MediaControl(const QString &configFile, Type t, int actions, QWidget *parent, const char *name)
 	: KPanelApplet(configFile, t, actions, parent, name), DCOPObject("MediaControl"),
-	_instance(new KInstance("mediacontrol"))
+		_instance(new KInstance("mediacontrol"))
 {
 	_player = 0L;
 	_prefsDialog = 0L;
@@ -104,15 +99,14 @@ MediaControl::MediaControl(const QString &configFile, Type t, int actions, QWidg
 	time_slider->setRange(0,0);
 	time_slider->setValue(0);
 	time_slider->setTracking( false );
-    
+
 	// request notification of changes in icon style
 	kapp->addKipcEventMask(KIPC::IconChanged);
-	connect(kapp, SIGNAL(iconChanged(int)), this, SLOT(slotIconChanged(int)));
+	connect(kapp, SIGNAL(iconChanged(int)), this, SLOT(slotIconChanged()));
 
 	reparseConfig();
 }
 
-
 MediaControl::~MediaControl()
 {
 	delete _player;
@@ -120,10 +114,8 @@ MediaControl::~MediaControl()
 	delete _dcopClient;
 }
 
-
 // Drag-n-Drop stuff ==================================================================
 
-
 void MediaControl::dragEnterEvent(QDragEnterEvent* event)
 {
 	_player->dragEnterEvent(event);  // Just pass dnd to the playerInterface
@@ -134,25 +126,24 @@ void MediaControl::dropEvent(QDropEvent* event)
 	_player->dropEvent(event);  // Just pass dnd to the playerInterface
 }
 
-
 // ====================================================================================
 
 
-
 void MediaControl::setSliderPosition(int len ,int time)
 {
 	time_slider->blockSignals ( true );
-	
+	if( orientation() == Vertical)
+	  time = len - time;
+
 	if ( lastLen != len )
-		time_slider->setRange(0,len);
+	  time_slider->setRange(0,len);
 	lastLen = len;
-	
+
 	if ( lastTime != time )
-		time_slider->setValue ( time );
+	  time_slider->setValue ( time );
 	lastTime = time;
 
 	time_slider->blockSignals ( false );
-
 }
 
 void MediaControl::enableAll(void)
@@ -175,9 +166,9 @@ void MediaControl::disableAll(void)
 	time_slider->setDisabled(true);
 }
 
-void MediaControl::slotIconChanged(int)
+void MediaControl::slotIconChanged()
 {
-	if( !_configFrontend->useCustomTheme() )
+	if(!_configFrontend->useCustomTheme())
 	{
 		prev_button->setPixmap ( SmallIcon("player_start.png") );
 		play_button->setPixmap ( SmallIcon("1rightarrow.png") );
@@ -187,18 +178,10 @@ void MediaControl::slotIconChanged(int)
 	}
 }
 
-
 // Dialogs ============================================================================
 
-
 void MediaControl::preferences(void)
 {
-/*
-	KProcess p;
-	p << KGlobal::dirs()->findResource("exe", "kcmshell");
-	p << "kcmmediacontrol";
-	p.start(KProcess::DontCare);
-*/
 	if ( _prefsDialog )
 	{
 		_prefsDialog->raise();
@@ -214,19 +197,16 @@ void MediaControl::preferences(void)
 
 void MediaControl::slotConfigChanged( void )
 {
-//	kdDebug() << "MediaControl::slotConfigChanged()" << endl;
 	reparseConfig();
 }
 
 void MediaControl::slotClosePrefsDialog()
 {
-//	kdDebug() << "MediaControl::slotClosePrefsDialog()" << endl;
 	delete _prefsDialog;
 }
 
 void MediaControl::slotPrefsDialogClosing()
 {
-//	kdDebug() << "MediaControl::slotPrefsDialogClosing()" << endl;
 	if ( _prefsDialog )
 		_prefsDialog = 0L;
 }
@@ -234,15 +214,21 @@ void MediaControl::slotPrefsDialogClosing()
 void MediaControl::about(void)
 {
 
-	KAboutData aboutData( "MediaControl", I18N_NOOP("MediaControl"), VERSION,
+	KAboutData aboutData( "MediaControl", I18N_NOOP("MediaControl"), MEDIACONTROL_VERSION,
 		I18N_NOOP("A small control-applet for various media players"),
-	KAboutData::License_GPL_V2, "(c) 2001 Stefan Gehn");
+		KAboutData::License_GPL_V2, "(c) 2001-2003 Stefan Gehn",
+		0, "http://metz.gehn.net");
+
+	aboutData.addAuthor("Stefan Gehn", I18N_NOOP("Main Developer"), "sgehn@gmx.net",
+		"http://metz.gehn.net");
+	aboutData.addAuthor("Robbie Ward", I18N_NOOP("Initial About-Dialog"), "wardy@robbieward.co.uk",
+		"http://www.robbieward.co.uk");
 
-	aboutData.addAuthor("Stefan Gehn", I18N_NOOP("Main Developer"), "sgehn@gmx.net", 0);
-	aboutData.addAuthor("Robbie Ward", I18N_NOOP("About-Dialog"), "linuxphreak@gmx.co.uk",
-		"http://linuxphreak.rox0rs.net");
 	aboutData.addCredit("Sascha Hoffman", I18N_NOOP("Button-Pixmaps"), "tisch.sush@gmx.de", 0);
-	aboutData.addCredit("Christian Hoffman", I18N_NOOP("Button-Pixmaps"), "tisch.crix@gmx.de", 0);
+	aboutData.addCredit("Christian Hoffman", I18N_NOOP("Button-Pixmaps"), "tisch.crix@gmx.de",
+		"http://www.crixensgfxcorner.de.vu/");
+	aboutData.addCredit("Ulrik Mikaelsson", I18N_NOOP("Fix for Noatun-Support"), "rawler@rsn.bth.se", 0);
+	aboutData.addCredit("Anthony J Moulen", I18N_NOOP("Fix for Vertical Slider"), "ajmoulen@moulen.org", 0);
 
 	KAboutApplication mediacontrolabout(&aboutData);
 
@@ -250,10 +236,17 @@ void MediaControl::about(void)
 	mediacontrolabout.exec();
 }
 
+// Fixing the orientation problem in qslider.
+void MediaControl::adjustTime(int time)
+{
+	if(orientation() == Vertical)
+		emit(newJumpToTime(lastLen - time));
+	else
+		emit(newJumpToTime(time));
+}
 
 // Config Stuff =======================================================================
 
-
 void MediaControl::reparseConfig()
 {
 //	kdDebug() << "reparseConfig();" << endl;
@@ -287,24 +280,26 @@ void MediaControl::reparseConfig()
 	{
 //		kdDebug() << "player = XMMS" << endl;
 		_player = new XmmsInterface ();
-		time_slider->setSteps ( (_configFrontend->mouseWheelSpeed()*1000), (_configFrontend->mouseWheelSpeed()*1000) );
+		time_slider->setSteps((_configFrontend->mouseWheelSpeed()*1000),
+			(_configFrontend->mouseWheelSpeed()*1000));
 	}
 	else // player is noatun or something wrong was written to the config
 #endif
 	{
 //		kdDebug() << "player = Noatun" << endl;
 		_player = new NoatunInterface();
-		time_slider->setSteps ( (_configFrontend->mouseWheelSpeed()), (_configFrontend->mouseWheelSpeed()) );
+		time_slider->setSteps((_configFrontend->mouseWheelSpeed()),
+			(_configFrontend->mouseWheelSpeed()));
 	}
 
 	//  this signal gets emitted by a playerInterface when the player's playtime changed
-	connect( _player, SIGNAL(newSliderPosition(int,int)), SLOT(setSliderPosition(int,int)));
+	connect(_player, SIGNAL(newSliderPosition(int,int)), SLOT(setSliderPosition(int,int)));
 
-	connect( _player, SIGNAL(playerStarted()), SLOT(enableAll()));
-	connect( _player, SIGNAL(playerStopped()), SLOT(disableAll()));
+	connect(_player, SIGNAL(playerStarted()), SLOT(enableAll()));
+	connect(_player, SIGNAL(playerStopped()), SLOT(disableAll()));
 
 	// do we use our icons or the default ones from KDE?
-	if ( _configFrontend->useCustomTheme() )
+	if(_configFrontend->useCustomTheme())
 	{
 		// load theme
 		QString skindir = locate("data", "mediacontrol/"+_configFrontend->theme()+"/");
@@ -338,23 +333,22 @@ void MediaControl::reparseConfig()
 
 	slider_tooltip = new MediaControlToolTip(time_slider, _player);
 
-	connect( prev_button , SIGNAL(clicked()), _player, SLOT(prev()) );
-	connect( play_button , SIGNAL(clicked()), _player, SLOT(play()) );
-	connect( pause_button, SIGNAL(clicked()), _player, SLOT(pause()) );
-	connect( stop_button , SIGNAL(clicked()), _player, SLOT(stop()) );
-	connect( next_button , SIGNAL(clicked()), _player, SLOT(next()) );
+	connect(prev_button, SIGNAL(clicked()), _player, SLOT(prev()));
+	connect(play_button, SIGNAL(clicked()), _player, SLOT(play()));
+	connect(pause_button, SIGNAL(clicked()), _player, SLOT(pause()));
+	connect(stop_button, SIGNAL(clicked()), _player, SLOT(stop()));
+	connect(next_button, SIGNAL(clicked()), _player, SLOT(next()));
 
-	connect( time_slider , SIGNAL(sliderPressed()), _player, SLOT(sliderStartDrag()) );
-	connect( time_slider , SIGNAL(sliderReleased()), _player, SLOT(sliderStopDrag()) );
-	connect( time_slider , SIGNAL(valueChanged(int)), _player, SLOT(jumpToTime(int)) );
+	connect(time_slider, SIGNAL(sliderPressed()), _player, SLOT(sliderStartDrag()));
+	connect(time_slider, SIGNAL(sliderReleased()), _player, SLOT(sliderStopDrag()));
+	connect(time_slider, SIGNAL(valueChanged(int)), this, SLOT(adjustTime(int)));
+	connect(this, SIGNAL(newJumpToTime(int)), _player, SLOT(jumpToTime(int)));
 }
 
-
 // Widget Placement ===================================================================
 
-
-	// kicker wants to know what width we need for a given height
-	// (this is called when being a HORIZONTAL panel)
+// kicker wants to know what width we need for a given height
+// (this is called when being a HORIZONTAL panel)
 int MediaControl::widthForHeight(int height) const
 {
 //	kdDebug() << "kicker height: " << height << endl;
@@ -373,7 +367,6 @@ int MediaControl::widthForHeight(int height) const
 	}
 }
 
-
 // kicker wants to know what height we need for a given width
 // (this is called when being a VERTICAL panel)
 int MediaControl::heightForWidth(int width) const
@@ -395,7 +388,6 @@ int MediaControl::heightForWidth(int width) const
 }
 
 // Danger: Weird Code ahead! ;))
-
 void MediaControl::resizeEvent( QResizeEvent* )
 {
 //	kdDebug() << "resizeEvent()" << endl;
@@ -477,7 +469,7 @@ void TrayButton::drawButton(QPainter *p)
 {
 	QPixmap bg( size() );
 	QPainter pbg;
-	
+
 	pbg.begin(&bg);
 	pbg.fillRect(rect(), colorGroup().brush(QColorGroup::Background));
 	if ( isDown() || isOn() )
@@ -494,12 +486,11 @@ void TrayButton::drawButton(QPainter *p)
 	p->drawPixmap(0,0,bg); // draw the background
 
 	// draw icon
-	if ( !pixmap()->isNull() )
+	if(!pixmap()->isNull())
 	{
 		QRect br(1, 1, width()-2, height()-2);
-		int dx = (br.width()   - pixmap()->width())   / 2;
-		int dy = (br.height()  - pixmap()->height())  / 2;
-
+		int dx = (br.width() - pixmap()->width()) / 2;
+		int dy = (br.height() - pixmap()->height()) / 2;
 		p->drawPixmap(br.x() + dx, br.y() + dy, *pixmap());
 	}
 }
