@@ -26,7 +26,7 @@
 #include <khtml_part.h>
 
 typedef KGenericFactory<PluginBabelFish> BabelFishFactory;
-K_EXPORT_COMPONENT_FACTORY( libbabelfishplugin, BabelFishFactory( "babelfish" ) );
+K_EXPORT_COMPONENT_FACTORY( libbabelfishplugin, BabelFishFactory( "babelfish" ) )
 
 PluginBabelFish::PluginBabelFish( QObject* parent, const char* name,
 	                          const QStringList & )
