@@ -41,7 +41,7 @@
 
 typedef KGenericFactory<DirFilterPlugin> DirFilterFactory;
 K_EXPORT_COMPONENT_FACTORY(libdirfilterplugin,
-                           DirFilterFactory("dirfilterplugin"));
+                           DirFilterFactory("dirfilterplugin"))
 
 SessionManager* SessionManager::m_self = 0;
 static KStaticDeleter<SessionManager> dirfiltersd;
