@@ -99,7 +99,7 @@ protected:
     QString iconName;
     QString mimeComment;
 
-    QStringList filenames;
+    QMap<QString, bool> filenames;
   };
 
   void loadSettings();
