@@ -1,4 +1,4 @@
-/* $Id: plugin_domtreeviewer.cpp,v 1.9 2002/07/16 07:52:15 binner Exp $ */
+/* $Id: plugin_domtreeviewer.cpp,v 1.9.2.1 2003/07/18 00:59:44 mueller Exp $ */
 
 #include "plugin_domtreeviewer.h"
 
@@ -13,7 +13,7 @@
 #include <domtreeview.h>
 
 typedef KGenericFactory<PluginDomtreeviewer> DomtreeviewerFactory;
-K_EXPORT_COMPONENT_FACTORY( libdomtreeviewerplugin, DomtreeviewerFactory( "domtreeviewer" ) );
+K_EXPORT_COMPONENT_FACTORY( libdomtreeviewerplugin, DomtreeviewerFactory( "domtreeviewer" ) )
 
 PluginDomtreeviewer::PluginDomtreeviewer( QObject* parent, const char* name,
 	                                  const QStringList & )
