@@ -35,7 +35,7 @@
 
 typedef KGenericFactory<SettingsPlugin> SettingsPluginFactory;
 K_EXPORT_COMPONENT_FACTORY( libkhtmlsettingsplugin,
-                            SettingsPluginFactory( "khtmlsettingsplugin" ) );
+                            SettingsPluginFactory( "khtmlsettingsplugin" ) )
 
 SettingsPlugin::SettingsPlugin( QObject* parent, const char* name,
                                 const QStringList & )
@@ -140,6 +140,7 @@ void SettingsPlugin::showPopup()
             ((KSelectAction*)actionCollection()->action("cachepolicy"))->setCurrentItem( 1 );
             break;
         case KIO::CC_Reload: // nothing for now
+        case KIO::CC_Refresh:
             break;
     };
 }
