@@ -41,7 +41,7 @@ Boston, MA 02111-1307, USA.
 #include "imgalleryplugin.h"
 
 typedef KGenericFactory<KImGalleryPlugin> KImGalleryPluginFactory;
-K_EXPORT_COMPONENT_FACTORY( libkimgallery, KImGalleryPluginFactory( "imgalleryplugin" ) );
+K_EXPORT_COMPONENT_FACTORY( libkimgallery, KImGalleryPluginFactory( "imgalleryplugin" ) )
 
 KImGalleryPlugin::KImGalleryPlugin( QObject* parent, const char* name, const QStringList & )
   : KParts::Plugin( parent, name ), m_commentMap(0)
