@@ -18,12 +18,10 @@
 */
 
 #include <kiconloader.h>
-#include <kurl.h>
 #include <kapplication.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kfiledialog.h>
-#include <kurl.h>
 #include <konq_popupmenu.h>
 
 #include <qpixmap.h>
@@ -35,8 +33,8 @@
 #include "kdirmenu.h"
 #include "kmetamenu.moc"
 
-KMetaMenu::KMetaMenu( QWidget *parent, const KURL &url, 
-        const QString &text, const QString &key) 
+KMetaMenu::KMetaMenu( QWidget *parent, const KURL &url,
+        const QString &text, const QString &key)
 : QPopupMenu( parent),
   m_root( 0 ), m_home( 0 ), m_etc( 0 ), m_current( 0 ), m_browse( 0 ) {
      int recent_no;
@@ -56,16 +54,16 @@ KMetaMenu::KMetaMenu( QWidget *parent, const KURL &url,
      QString confDir = QDir::rootDirPath()+ "etc";
      if ( QFileInfo( confDir ).isWritable() )
      {
-         m_etc  = new KDirMenu( parent, url.path(), confDir, text ); 
-         insertItem( SmallIcon( "folder_yellow" ) , 
+         m_etc  = new KDirMenu( parent, url.path(), confDir, text );
+         insertItem( SmallIcon( "folder_yellow" ) ,
                  i18n("&System Configuration"), m_etc);
          dirList << confDir;
 
-         connect(m_etc , SIGNAL(fileChosen(const QString &)), 
-                 SLOT(slotFileChosen(const QString &) ) ); 
+         connect(m_etc , SIGNAL(fileChosen(const QString &)),
+                 SLOT(slotFileChosen(const QString &) ) );
      }
 
-     if ( url.isLocalFile() 
+     if ( url.isLocalFile()
              && dirList.find( url.path() ) == dirList.end()
              && QFileInfo( url.path() ).isWritable() )
      {
@@ -73,16 +71,19 @@ KMetaMenu::KMetaMenu( QWidget *parent, const KURL &url,
          m_current = new KDirMenu( parent, url.path(), url.path(), text );
          insertItem( SmallIcon( "folder_blue" ), i18n( "&Current Directory" ),
                  m_current );
+
+	 connect(m_current, SIGNAL(fileChosen(const QString &)),
+                 SLOT(slotFileChosen(const QString &) ) );
      }
 
-     connect(m_root, SIGNAL(fileChosen(const QString &)), 
-             SLOT(slotFileChosen(const QString &) ) ); 
-     connect(m_home, SIGNAL(fileChosen(const QString &)), 
-             SLOT(slotFileChosen(const QString &) ) ); 
+     connect(m_root, SIGNAL(fileChosen(const QString &)),
+             SLOT(slotFileChosen(const QString &) ) );
+     connect(m_home, SIGNAL(fileChosen(const QString &)),
+             SLOT(slotFileChosen(const QString &) ) );
 
      m_browse = new KAction(i18n("&Browse..."), 0, this, SLOT(slotBrowse()), this );
      m_browse->plug(this);
-     // read the last chosen dirs 
+     // read the last chosen dirs
      // first set the group according to our parameter
      conf = kapp->config( );
      conf->setGroup(key );
@@ -92,7 +93,7 @@ KMetaMenu::KMetaMenu( QWidget *parent, const KURL &url,
          insertSeparator();
      int i=1;
      for( QStringList::Iterator it =list.begin(); it != list.end(); ++it) {
-         if( i == (recent_no + 1) ) 
+         if( i == (recent_no + 1) )
 	     break;
          KAction *action = new KAction(*it, 0, this, SLOT(slotFastPath() ), this );
          action->plug(this );
@@ -118,7 +119,7 @@ void KMetaMenu::slotFileChosen(const QString &path ){
 void KMetaMenu::slotFastPath( ) {
      KAction *action;
      action = (KAction*) sender();
-     QString text = action->plainText( ); 
+     QString text = action->plainText( );
      slotFileChosen( text );
 }
 void KMetaMenu::writeConfig( const QString &path){
