@@ -201,7 +201,7 @@ bool SmbmounterPlugin::isMounted(const QString& path)
    return (mtabContents.contains(path));
 }
 
-K_EXPORT_COMPONENT_FACTORY( konq_smbmounterplugin, KGenericFactory<SmbmounterPlugin> );
+K_EXPORT_COMPONENT_FACTORY( konq_smbmounterplugin, KGenericFactory<SmbmounterPlugin> )
 
 #include "smbmounterplugin.moc"
 
