@@ -45,7 +45,7 @@
 
 typedef KGenericFactory<UAChangerPlugin> UAChangerPluginFactory;
 K_EXPORT_COMPONENT_FACTORY( libuachangerplugin,
-	                    UAChangerPluginFactory( "uachangerplugin" ) );
+	                    UAChangerPluginFactory( "uachangerplugin" ) )
 
 UAChangerPlugin::UAChangerPlugin( QObject* parent, const char* name,
                                   const QStringList & )
