@@ -17,12 +17,12 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: webarchivecreator.h,v 1.1 2001/06/24 21:51:06 schlpbch Exp $
+// $Id: webarchivecreator.h,v 1.2 2001/10/05 11:16:05 mueller Exp $
 // 
 #ifndef __webarchivecreator_h__
 #define __webarchivecreator_h__
 
-#include "thumbcreator.h"
+#include <kio/thumbcreator.h>
 
 class KHTMLPart;
 
