@@ -36,6 +36,7 @@
 
 #include <kstatusbar.h>
 #include <kpopupmenu.h>
+#include <kurldrag.h>
 #include <kglobal.h>
 #include <kconfig.h>
 #include <klocale.h>
@@ -175,14 +176,11 @@ void AlsaPlayer::dragEnterEvent(QDragEnterEvent *event)
 
 void AlsaPlayer::dropEvent(QDropEvent *event)
 {
-	QStringList uriList;
-
-	if (QUriDrag::decodeToUnicodeUris(event, uriList))
+	KURL::List uri;
+	if (KURLDrag::decode(event, uri))
 	{
-		QStringList::ConstIterator it(uriList.begin());
-
-		for (; it != uriList.end(); ++it)
-			napp->player()->openFile(KURL(*it), false);
+		for (KURL::List::Iterator i = uri.begin(); i !=	uri.end(); ++i)
+			napp->player()->openFile(*i, false);
 	}
 }
 
