@@ -6,7 +6,7 @@
 #ifndef KOSDH
 #define KOSDH
 #include <sys/types.h>
-#include <qqueue.h>
+#include <qptrqueue.h>
 #include <qobject.h>
 #include <qtimer.h>
 #include <qlabel.h>
