@@ -2,7 +2,7 @@
 #define NEXPLUG_H
 
 #include <kprocess.h>
-#include <plugin.h>
+#include <noatun/plugin.h>
 
 class NexPlugin : public QObject, public Plugin
 {
